InfiniteQueryError<TData, TError, TPageParam> class final

The infinite query encountered an error.

This is an experimental API and may change in a future minor release.

Inheritance

Constructors

InfiniteQueryError({required TError error, required InfiniteData<TData, TPageParam>? data, required FetchStatus fetchStatus, required DateTime? dataUpdatedAt, required int dataUpdateCount, required DateTime? errorUpdatedAt, required int errorUpdateCount, required int failureCount, required TError? failureReason, required bool isEnabled, required bool isStale, required bool isFetchedAfterMount, required InfiniteRefetch<TData, TError, TPageParam> refetch, required FetchNextPage<TData, TError, TPageParam> fetchNextPage, required FetchPreviousPage<TData, TError, TPageParam> fetchPreviousPage, required bool hasNextPage, required bool hasPreviousPage, required bool isFetchingNextPage, required bool isFetchingPreviousPage, required bool isFetchNextPageError, required bool isFetchPreviousPageError})
Creates an error snapshot.
const

Properties

data InfiniteData<TData, TPageParam>?
The last successfully accumulated pages, if any, preserved across the error.
final
dataOrNull InfiniteData<TData, TPageParam>?
The accumulated pages, if any.
no setteroverride
dataUpdateCount int
The number of times the data has been updated.
finalinherited
dataUpdatedAt DateTime?
The timestamp when the data was last updated.
finalinherited
error → TError
The error thrown by the last failed fetch.
final
errorUpdateCount int
The number of times the error has been updated.
finalinherited
errorUpdatedAt DateTime?
The timestamp when the error was last updated.
finalinherited
failureCount int
The number of times the current fetch has failed.
finalinherited
failureReason → TError?
The error from the most recent failed fetch attempt.
finalinherited
fetchNextPage → FetchNextPage<TData, TError, TPageParam>
Fetches the next page of data.
finalinherited
fetchPreviousPage → FetchPreviousPage<TData, TError, TPageParam>
Fetches the previous page of data.
finalinherited
fetchStatus FetchStatus
The current network activity state of the query.
finalinherited
hashCode int
The hash code for this object.
no setteroverride
hasNextPage bool
Whether there is a next page available.
finalinherited
hasPreviousPage bool
Whether there is a previous page available.
finalinherited
isEnabled bool
Whether this query is enabled and can fetch.
finalinherited
isError bool
Whether the query is in an error state.
no setterinherited
isFetched bool
Whether the query has fetched at least once.
no setterinherited
isFetchedAfterMount bool
Whether this query has been fetched after the observer mounted.
finalinherited
isFetching bool
Whether a fetch is currently in progress.
no setterinherited
isFetchingNextPage bool
Whether this query is currently fetching the next page.
finalinherited
isFetchingPreviousPage bool
Whether this query is currently fetching the previous page.
finalinherited
isFetchNextPageError bool
Whether the last fetch of the next page resulted in an error.
finalinherited
isFetchPreviousPageError bool
Whether the last fetch of the previous page resulted in an error.
finalinherited
isIdle bool
Whether no fetch is in progress.
no setterinherited
isLoading bool
Whether the query is fetching for the first time with no data.
no setterinherited
isLoadingError bool
Whether the query failed on its initial load with no prior data.
no setterinherited
isPaused bool
Whether the fetch is paused (typically offline).
no setterinherited
isPending bool
Whether the query has no resolved data yet.
no setterinherited
isRefetchError bool
Whether the query failed while refetching with existing data.
no setterinherited
isRefetching bool
Whether the query is refetching all pages in the background.
no setterinherited
isStale bool
Whether this query's data is considered stale.
finalinherited
isSuccess bool
Whether the query has resolved data.
no setterinherited
pageParams List<TPageParam>
The list of page parameters for all fetched pages.
no setterinherited
pages List<TData>
The list of all fetched pages.
no setterinherited
refetch → InfiniteRefetch<TData, TError, TPageParam>
Refetches all pages of the query.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override