isFetchPreviousPageError property
Whether the last fetch of the previous page resulted in an error.
Implementation
final bool isFetchPreviousPageError;
Whether the last fetch of the previous page resulted in an error.
final bool isFetchPreviousPageError;