isLoading property
bool
get
isLoading
Whether the query is fetching for the first time with no data.
Implementation
bool get isLoading => isPending && isFetching;
Whether the query is fetching for the first time with no data.
bool get isLoading => isPending && isFetching;