isLoadingError property
bool
get
isLoadingError
Whether the query failed on its initial load with no prior data.
Implementation
bool get isLoadingError => isError && dataOrNull == null;
Whether the query failed on its initial load with no prior data.
bool get isLoadingError => isError && dataOrNull == null;