isRefetchError property
bool
get
isRefetchError
Whether the query failed while refetching with existing data.
Implementation
bool get isRefetchError => isError && dataOrNull != null;
Whether the query failed while refetching with existing data.
bool get isRefetchError => isError && dataOrNull != null;