mutateAsync property
MutateAsync<TData, TVariables>
mutateAsync
final
A function that executes the mutation and returns a Future.
Implementation
final MutateAsync<TData, TVariables> mutateAsync;
A function that executes the mutation and returns a Future.
final MutateAsync<TData, TVariables> mutateAsync;